# This script generates a .bat file to be used in running a batch of CAL3QHC simulations.
# Users define the model executable name, the directory containing input files,
# and the directory to which output files will be written. The script then generates the 
# list of output and input files (full directory paths).
#
# Note: The text within the generated .bat file should be copied into a command window
# opened in the directory that contains the CAL3QHC model. Upon copying this text, the
# various model simulations will be conducted. On the last simulation (i.e., the instances
# of the model executable name, input file and output file, the user must press 'enter' as 
# there is no carriage return at the end of this line to have it run in the command line.
#
# Author: John Hader

# Clears the memory and the text on the console.
rm(list = ls())
cat("\014")

# User-defined inputs -----------------------------------------------------

# Input/output paths and base file definition.
# Note the .bat file from this script will be 
# written to the 'output_directory'.
#

input_directory <- "C:/Users/37880/Desktop/NCHRP/Runs/20%_Trucks/Interchanges_2019/03_Full_input_files_IN"
output_directory <- "C:/Users/37880/Desktop/NCHRP/Runs/20%_Trucks/Interchanges_2019/04_Output_files_IN" # Don't include trailing slash.

# File extensions (include period).
#
# QA'ed (JDH; 2019/09/01)
input_ext <- ".in2" # Only files w/this extention will be included in the .bat file.
output_ext <- ".ou2"

# Name of executable (don't include file extension).
#
# QA'ed (JDH; 2019/09/01)
executable_name <- "CAL3QHC"

# Name of output .bat file (include extenstion).
#
# QA'ed (JDH; 2019/11/01)
bat_file_name <- "01_Interchanges_IN_20%.bat"

#------ End User-defined Inputs--------

# Files processing ---------------------------------------------------------

# Character to replace the forward slashes in R directories (don't change).
out_sep <- "\\\\" # Do not change this.

# Determines list of input files.
input_files_full <- list.files(input_directory,pattern=paste("\\",input_ext,"$",sep=""),full.names=TRUE)
input_files_names <- list.files(input_directory,pattern=paste("\\",input_ext,"$",sep=""),full.names=FALSE)

# Generates output files names.
files_names <- substr(input_files_names,1,(nchar(input_files_names)-nchar(input_ext)))
output_files_full <- paste(output_directory,"/",files_names,output_ext,sep="")

# .bat file generation -----------------------------------------------------

# Stitches together executable, input, and output files.
output_lines <- paste(executable_name,input_files_full,output_files_full,sep=" ")
output_lines <- gsub("/",out_sep,output_lines)

# Writes out .bat file.
write(output_lines,paste(output_directory,"/",bat_file_name,sep=""))
